@@ -1,4 +1,4 @@
-# $Id: container.py 2013 2005-12-31 03:19:39Z zzzeek $
+# $Id: container.py 2062 2006-05-03 05:40:30Z dairiki $
 # container.py - file/memory data containment API and implementation for Myghty
 # Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
 #
@@ -496,7 +496,7 @@ class MemoryNamespaceManager(NamespaceManager):
         del self.dictionary[key]
 
     def do_remove(self):
-        del MemoryNamespaceManager.namespaces[self.namespace]
+        self.dictionary.clear()
         
     def keys(self):
         return self.dictionary.keys()
@@ -717,6 +717,7 @@ class FileNamespaceManager(NamespaceManager):
                 
     def do_remove(self):
         os.remove(self.file)
+        self.hash = {}
         
     def __getitem__(self, key): 
         return self.hash[key]
