@@ -1,4 +1,4 @@
-# $Id: exception.py 2028 2006-01-16 23:39:04Z zzzeek $
+# $Id: exception.py 2039 2006-02-05 06:58:40Z zzzeek $
 # exception.py - exception classes for Myghty
 # Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
 # Original Perl code and documentation copyright (c) 1998-2003 by Jonathan Swartz. 
@@ -511,7 +511,7 @@ class HTMLErrorFormatter(ErrorFormatter):
 
     <table>
     <tr><td class="bold">Error:</td>
-    <td><% message %></td>
+    <td><% message |h %></td>
     <tr><td class="bold">File:</td>
     <td><% lead_rec.file %> line <% lead_rec.codeline %></td>
     </tr>
