@@ -1,4 +1,4 @@
-# $Id: request.py 2053 2006-03-02 16:58:25Z zzzeek $
+# $Id: request.py 2061 2006-05-01 16:57:15Z zzzeek $
 # request.py - handles component calls for Myghty templates
 # Copyright (C) 2004, 2005 Michael Bayer mike_mp@zzzcomputing.com
 # Original Perl code and documentation copyright (c) 1998-2003 by Jonathan Swartz.
@@ -47,6 +47,7 @@ class Request(object):
         request_depth = 0,
         request_path = None,
         raise_error = False,
+        disable_wrapping = False,
         **params
         ):
         """init is called internally by the Interpreter."""
@@ -59,7 +60,7 @@ class Request(object):
         self.max_recursion = max_recursion
         self.dont_auto_flush_filters = dont_auto_flush_filters
         self.use_dhandlers = use_dhandlers
-    
+        self.disable_wrapping = disable_wrapping
         self.raise_error = raise_error
         self.parent_request = parent_request
 
@@ -257,7 +258,10 @@ class Request(object):
                     if depth >= self.max_recursion:
                         self._raise_error("Max %d levels deep in determining inheritance chain (recursive inheritance pattern?)" % depth);
 
-                first_component = self.wrapper_chain[-1]
+                if self.disable_wrapping:
+                    first_component = self.wrapper_chain[0]
+                else:
+                    first_component = self.wrapper_chain[-1]
 
                 result = None
                 try:
